@@ -28,7 +28,12 @@
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 from .bound_ops import LowerBound
-from .ops import quantize_ste
+from .ops import compute_padding, quantize_ste
 from .parametrizers import NonNegativeParametrizer
 
-__all__ = ["quantize_ste", "LowerBound", "NonNegativeParametrizer"]
+__all__ = [
+    "compute_padding",
+    "quantize_ste",
+    "LowerBound",
+    "NonNegativeParametrizer",
+]
