@@ -51,6 +51,7 @@ import compressai
 
 from compressai.datasets import RawVideoSequence, VideoFormat
 from compressai.models.video.google import ScaleSpaceFlow
+from compressai.ops import compute_padding
 from compressai.transforms.functional import (
     rgb2ycbcr,
     ycbcr2rgb,
@@ -69,8 +70,8 @@ RAWVIDEO_EXTENSIONS = (".yuv",)  # read raw yuv videos for now
 def collect_videos(rootpath: str) -> List[str]:
     video_files = []
     for ext in RAWVIDEO_EXTENSIONS:
-        video_files.extend(Path(rootpath).glob(f"*{ext}"))
-    return video_files
+        video_files.extend(Path(rootpath).rglob(f"*{ext}"))
+    return sorted(video_files)
 
 
 # TODO (racapef) duplicate from bench
@@ -118,19 +119,8 @@ def convert_rgb_to_yuv420(frame: Tensor) -> Tuple[np.ndarray, np.ndarray, np.nda
 
 def pad(x: Tensor, p: int = 2 ** (4 + 3)) -> Tuple[Tensor, Tuple[int, ...]]:
     h, w = x.size(2), x.size(3)
-    new_h = (h + p - 1) // p * p
-    new_w = (w + p - 1) // p * p
-    padding_left = (new_w - w) // 2
-    padding_right = new_w - w - padding_left
-    padding_top = (new_h - h) // 2
-    padding_bottom = new_h - h - padding_top
-    padding = (padding_left, padding_right, padding_top, padding_bottom)
-    x = F.pad(
-        x,
-        padding,
-        mode="constant",
-        value=0,
-    )
+    padding, _ = compute_padding(h, w, min_div=p)
+    x = F.pad(x, padding, mode="constant", value=0)
     return x, padding
 
 
@@ -358,6 +348,7 @@ def eval_model_entropy_estimation(net: nn.Module, sequence: Path) -> Dict[str, A
 
 def run_inference(
     filepaths,
+    inputdir: Path,
     net: nn.Module,
     outputdir: Path,
     force: bool = False,
@@ -369,7 +360,9 @@ def run_inference(
     results_paths = []
 
     for filepath in filepaths:
-        sequence_metrics_path = Path(outputdir) / f"{filepath.stem}-{trained_net}.json"
+        output_subdir = Path(outputdir) / Path(filepath).parent.relative_to(inputdir)
+        output_subdir.mkdir(parents=True, exist_ok=True)
+        sequence_metrics_path = output_subdir / f"{filepath.stem}-{trained_net}.json"
         results_paths.append(sequence_metrics_path)
 
         if force:
@@ -489,9 +482,9 @@ def create_parser() -> argparse.ArgumentParser:
         "-q",
         "--quality",
         dest="qualities",
-        nargs="+",
-        type=int,
-        default=(1,),
+        type=str,
+        default="1",
+        help="Pretrained model qualities. (example: '1,2,3,4') (default: %(default)s)",
     )
     checkpoint_parser = subparsers.add_parser("checkpoint", parents=[parent_parser])
     checkpoint_parser.add_argument(
@@ -534,6 +527,7 @@ def main(args: Any = None) -> None:
     Path(outputdir).mkdir(parents=True, exist_ok=True)
 
     if args.source == "pretrained":
+        args.qualities = [int(q) for q in args.qualities.split(",") if q]
         runs = sorted(args.qualities)
         opts = (args.architecture, args.metric)
         load_func = load_pretrained
@@ -563,6 +557,7 @@ def main(args: Any = None) -> None:
         args_dict = vars(args)
         metrics = run_inference(
             filepaths,
+            args.dataset,
             model,
             outputdir,
             trained_net=trained_net,
